@@ -5,16 +5,16 @@ import kubernetes
 
 from dagster import Field, MetadataEntry, StringSource
 from dagster import _check as check
-from dagster.cli.api import ExecuteRunArgs
-from dagster.core.events import EngineEventData
-from dagster.core.launcher import LaunchRunContext, ResumeRunContext, RunLauncher
-from dagster.core.launcher.base import CheckRunHealthResult, WorkerStatus
-from dagster.core.storage.pipeline_run import PipelineRun, PipelineRunStatus
-from dagster.core.storage.tags import DOCKER_IMAGE_TAG
-from dagster.grpc.types import ResumeRunArgs
-from dagster.serdes import ConfigurableClass, ConfigurableClassData
-from dagster.utils import frozentags, merge_dicts
-from dagster.utils.error import serializable_error_info_from_exc_info
+from dagster._cli.api import ExecuteRunArgs
+from dagster._core.events import EngineEventData
+from dagster._core.launcher import LaunchRunContext, ResumeRunContext, RunLauncher
+from dagster._core.launcher.base import CheckRunHealthResult, WorkerStatus
+from dagster._core.storage.pipeline_run import PipelineRun, PipelineRunStatus
+from dagster._core.storage.tags import DOCKER_IMAGE_TAG
+from dagster._grpc.types import ResumeRunArgs
+from dagster._serdes import ConfigurableClass, ConfigurableClassData
+from dagster._utils import frozentags, merge_dicts
+from dagster._utils.error import serializable_error_info_from_exc_info
 
 from .container_context import K8sContainerContext
 from .job import (
